import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { useState, useEffect } from "react";
import { Stack, Card, CardHeader, Heading, CardBody, Text, Button } from "@chakra-ui/react";
import { useCamera } from '../hooks/use-camera.js';
import { useGallery } from '../hooks/use-gallery.js';
import { downloadImages } from '../download-images.js';
import { isIOS, isAndroid } from "react-device-detect";
import { ImageCard } from "./image-card.js";
import { useContainer } from "../hooks/use-container.js";
import { usePermissions } from "../hooks/use-permissions.js";
/**
 * React component for using the camera.
 * @param {DeepClient} deep - The DeepClient object instance.
 */
export function CapacitorCamera({ deep, containerLinkId: passedContainerLinkId }) {
    const [images, setImages] = useState([]); // State variable for storing images downloaded from deep database.
    const containerLinkIdFromHook = useContainer(deep); // Retrieve the container link ID.
    const [containerLinkId, setContainerLinkId] = useState(passedContainerLinkId || containerLinkIdFromHook);
    useEffect(() => {
        setContainerLinkId(passedContainerLinkId || containerLinkIdFromHook);
    }, [deep, passedContainerLinkId, containerLinkIdFromHook]);
    const { cameraPermissions, getPermissions } = usePermissions(); // Get camera permissions.
    const { galleryPhotos, pickPhotosFromGallery } = useGallery({ deep, containerLinkId }); // Custom hook for using the gallery.
    const { photos, newPhoto } = useCamera({ deep, containerLinkId }); // Custom hook for taking a new photo with the camera.
    return (_jsxs(_Fragment, { children: [_jsxs(Stack, { children: [_jsxs(Card, { align: "center", children: [_jsx(CardHeader, { children: _jsx(Heading, { children: "CAMERA" }) }), !(isAndroid && isIOS)
                                ? null
                                : (_jsxs(_Fragment, { children: [_jsx(CardHeader, { children: _jsx(Heading, { children: "Permissions" }) }), _jsx(CardBody, { children: _jsxs(Stack, { align: "center", spacing: 4, children: [_jsx(Text, { children: `Camera Permissions are ${!cameraPermissions?.camera ? 'not' : ''} granted.` }), _jsx(Text, { children: `Gallery Permissions are ${!cameraPermissions?.photos ? 'not' : ''} granted.` }), _jsx(Button, { onClick: async () => await getPermissions(), children: "REQUEST PERMISSIONS" })] }) })] }))] }), _jsx(Button, { onClick: newPhoto, children: _jsx(Text, { children: "USE CAMERA" }) }), _jsx(Button, { onClick: pickPhotosFromGallery, children: _jsx(Text, { children: "USE GALLERY" }) }), _jsx(Button, { onClick: async () => { const images = await downloadImages(deep); setImages(images); }, children: _jsx(Text, { children: "LOAD IMAGES" }) })] }), _jsx(Stack, { align: "center", direction: "column", children: images?.map((image) => _jsx(ImageCard, { image: image }, image.id)) })] }));
}
