import { useEffect } from 'react';
import { useLocalStore } from '@deep-foundation/store/local.js';
import { pickGalleryPhotos } from '../pick-photos.js';
import { uploadGallery } from '../upload-gallery.js';
/**
 * Custom hook for using the gallery to pick photos and upload them.
 * @param {IUseGalleryOptions} params - The parameters for using the gallery.
 * @returns {Function} A function to pick photos from the gallery.
 */
export const useGallery = ({ deep, containerLinkId, options }) => {
    const [galleryPhotos, setGalleryPhotos] = useLocalStore("GalleryPhotos", []); // State for storing the gallery photos.
    useEffect(() => {
        const upload = async () => {
            await uploadGallery({ deep, containerLinkId, galleryPhotos }); // Upload the gallery photos.
            setGalleryPhotos([]); // Clear the gallery photos after upload.
        };
        if (galleryPhotos.length > 0) {
            upload(); // Trigger the upload process when there are photos in the gallery.
        }
    }, [galleryPhotos, deep]);
    /**
     * Function to pick photos from the gallery and add them to the state.
     */
    const pickPhotosFromGallery = async () => {
        const newGalleryPhotos = await pickGalleryPhotos(options); // Pick new photos from the gallery.
        setGalleryPhotos([...galleryPhotos, ...newGalleryPhotos]); // Add the new photos to the state.
    };
    return { galleryPhotos, pickPhotosFromGallery }; // Return the function for picking photos from the gallery.
};
